@@ -21,14 +21,21 @@ from zope.configuration.fields import GlobalObject
 from ore.xapian import MessageFactory as _
 from ore.xapian import queue
 
+import interfaces
+
 class IQueueDirective(Interface):
     indexer = GlobalObject(
         title=_("Xapian indexer"),
         required=True)
 
 def queueDirective(_context, indexer):
+    
+    if interfaces.DEBUG_SYNC:
+        return
+    
     # start the processing thread
-    queue.QueueProcessor.start(indexer)
+
+    queue.QueueProcessor.start(indexer, silent=True)
 
     
     
